# PyLol #

A Module to reduce imports

## Status ##

Current Verison: 0.1
Author: BXRCODES
License: MIT License

### Description ###

Python has so many packages to offer, but perhaps a bit too many. Are your imports looking messy? Well PyLol is the solution for all of that. Simply put a couple of imports rather than 100 and still get the same results!

#### Usage ####

Use PyLol for many things like Async Development and Opening Files, manipulate JSON Files, Do Maths and many more

##### License #####

MIT License
See LICENSE for more details

###### Patch Notes ######

#New:#
Random Class was Added to the Package

##INITIAL RELEASE##

All new functions in define state:
# ALL THE FUNCTIONS WILL HAVE THE SAME NAMES AS THEIR PROPER MODULES SO WHEN USING THEM, YOU DON'T NEED TO LEARN ANY NEW SYNTAX #
	seed(a=None, version=2)

	getstate()

	setstate(state)

	getrandbits(k)

	randrange(start, stop)

	randint(a, b)

	choice(seq)

	choices(population, weights=None, *, cum_weights=None, k=1)

	shuffle(x)

	sample(population, k)

	random()

	uniform(a,b)

	triangular(low, high, mode)

	betavariate(alpha, beta)

	expovariate(lambd)

	gammavariate(alpha, beta)

	gauss(mu, sigma)

	lognormvariate(mu, sigma)

	normalvariate(mu, sigma)

	vonmisesvariate(mu, kappa)

	paretovariate(alpha)

	weibullvariate(alpha, beta)
